@@ -1,11 +1,12 @@
-#!/usr/bin/python3.10
+#!/usr/bin/python3.13
 
 import sys
+
+from osgeo.gdal import deprecation_warn
+
 # import osgeo_utils.gdal_proximity as a convenience to use as a script
 from osgeo_utils.gdal_proximity import *  # noqa
 from osgeo_utils.gdal_proximity import main
-from osgeo.gdal import deprecation_warn
 
-
-deprecation_warn('gdal_proximity')
+deprecation_warn("gdal_proximity")
 sys.exit(main(sys.argv))
